@@ -155,7 +155,7 @@ class Base(Controller):
 
 
     @ex(
-        help='Monitor (lack of) GPU activity. Remeber to add & at the end',
+        help='Monitor lack of GPU activity. When there is none, runs -job',
         arguments=[
             (['-job'],{
                 "help" : "Text of the command to run after no GPU activity",
